@@ -8,6 +8,8 @@
 # Created Time:  2022-4-25 10:17:34
 # Description: 有关word的自动化操作
 #############################################
+from office.lib.utils.except_utils import except_dec
+
 from office.core.WordType import MainWord
 
 # 创建对象
@@ -17,5 +19,6 @@ mainWord = MainWord()
 # 1、文件的批量转换
 # 自己指定路径，
 # 为了适配wps不能转换doc的问题，这里限定：只能转换docx
+@except_dec()
 def docx2pdf(path):
     mainWord.file2pdf(path)
