@@ -1,9 +1,12 @@
-import os
 from fpdf import FPDF
 from office.lib.pdf import add_watermark_service
 import pikepdf
 from PyPDF2 import PdfFileReader, PdfFileWriter
 from pdf2docx import Converter
+import os
+import datetime
+
+import fitz  # fitz就是pip install PyMuPDF
 
 
 class MainPDF():
@@ -77,3 +80,21 @@ class MainPDF():
         pdf = pikepdf.open(path, password=password)
         pdf.save(res_pdf)
         pdf.close()
+
+    def pdf2imgs(self, pdf_path: str, out_dir=".") -> None:
+
+        pdfDoc = fitz.open(pdf_path)
+        for pg in range(pdfDoc.pageCount):
+            page = pdfDoc[pg]
+            rotate = int(0)
+            # 每个尺寸的缩放系数为1.3，这将为我们生成分辨率提高2.6的图像。
+            # 此处若是不做设置，默认图片大小为：792X612, dpi=96
+            zoom_x = 1.33333333  # (1.33333333-->1056x816)   (2-->1584x1224)
+            zoom_y = 1.33333333
+            mat = fitz.Matrix(zoom_x, zoom_y).preRotate(rotate)
+            pix = page.getPixmap(matrix=mat, alpha=False)
+
+            if not os.path.exists(out_dir):  # 判断存放图片的文件夹是否存在
+                os.makedirs(out_dir)  # 若图片文件夹不存在就创建
+
+            pix.writePNG(out_dir + '/' + 'images_%s.png' % pg)  # 将图片写入指定的文件夹内
