@@ -1,8 +1,7 @@
 import unittest
 
-from office.image import add_watermark
-from office.tools import url2ip, weather
-
+from office.api.image import add_watermark
+from office.api.tools import url2ip, weather, lottery8ticket
 
 
 class TestTools(unittest.TestCase):
@@ -14,4 +13,9 @@ class TestTools(unittest.TestCase):
         url2ip('www.python-office.com')
 
     def test_image_watermark(self):
-        add_watermark(file=r'.\目录结构.jpg',mark='程序员晚枫')
+        add_watermark(file=r'.\目录结构.jpg', mark='程序员晚枫')
+
+    def test_lottery8ticket(self):
+        lottery8ticket()
+
+
